@@ -7,7 +7,7 @@ use Time::Local;
 use WWW::IndexParser::Entry;
 
 BEGIN {
-  our $VERSION = '0.5.1';
+  our $VERSION = 0.1;
 }
 
 our $months = {
@@ -48,12 +48,8 @@ sub new {
  if (defined $args{proxy}) {
    $self->{ua}->proxy('http', $args{proxy});
  }
- if (defined $args{debug}) {
-   $self->{debug} = $args{debug};
- } else {
-   $self->{debug} = 0;
- }
  $self->{parser} = HTML::Parser->new( api_version => 3);
+ #$self->{debug} = 1;
  if (defined $args{url}) {
    $self->_url($args{url});
    return @{$self->{files}} if defined $self->{files};
@@ -68,7 +64,7 @@ sub _url {
   my $self = shift;
   if (@_) {
     my $new_url = shift;
-    warn "The URL was $new_url" if $self->{debug};
+    #warn "The URL was $new_url" if defined $self->{debug};
 
     $self->{url} = $new_url;
     if ($new_url =~ /^([^:]+):\/\/([^:\/]+)(:(\d+))?/) {
@@ -86,34 +82,25 @@ sub _url {
       return;
     }
 
-    if (ref($self->{res}->headers->{'content-type'}) eq "ARRAY") {
-      my $found_html = 0;
-      foreach (@{$self->{res}->headers->{'content-type'}}) {
-        $found_html = 1 if /^text\/html/;
-      }
-      if (not $found_html) {
-        warn "Not an HTML page " . $self->{res}->headers->{'content-type'};
-        return;
-      }
-    } elsif ($self->{res}->headers->{'content-type'} !~ /^text\/html/) {
-     warn "Not an HTML page " . $self->{res}->headers->{'content-type'};
-     return;
-   }
+    if ($self->{res}->headers->{'content-type'} !~ /^text\/html/) {
+      warn "Not an HTML page " . $self->{res}->headers->{'content-type'};
+      return;
+    }
 
     if ($self->{res}->headers->{server} =~ /^Apache-Coyote/) {
-      warn "Server is Tomcat Coyote" if $self->{debug};
+      warn "Server is Tomcat Coyote" if defined $self->{debug};
       $self->{parser}->handler( start => \&_parse_html_tomcat, "self, tagname, attr, attrseq, text");
       $self->{parser}->handler( text => \&_parse_html_tomcat, "self, tagname, attr, attrseq, text");
     } elsif ($self->{res}->headers->{server} =~ /^Apache/) {
-      warn "Server is Apache" if $self->{debug};
+      warn "Server is Apache" if defined $self->{debug};
       $self->{parser}->handler( start => \&_parse_html_apache, "self, tagname, attr, attrseq, text");
       $self->{parser}->handler( text => \&_parse_html_apache, "self, tagname, attr, attrseq, text");
     } elsif ($self->{res}->headers->{server} =~ /^Microsoft-IIS/) {
-      warn "Server is IIS" if $self->{debug};
+      warn "Server is IIS" if defined $self->{debug};
       $self->{parser}->handler( start => \&_parse_html_iis, "self, tagname, attr, attrseq, text");
       $self->{parser}->handler( text => \&_parse_html_iis, "self, tagname, attr, attrseq, text");
     } else {
-      warn "Unknown web server" if $self->{debug};
+      warn "Unknown web server" if defined $self->{debug};
       return;
     }
 
@@ -143,7 +130,7 @@ sub _parse_html_tomcat {
     return unless $self->{parser_state};
 
     if ($self->{parser_state} == 2) {
-      warn "The title is: $origtext" if $self->{debug};
+      warn "The title is: $origtext" if defined $self->{debug};
       if ($origtext =~ /^Directory Listing For (.+)$/) {
         $self->{directory} = $1;
       }
@@ -182,8 +169,8 @@ sub _parse_html_tomcat {
     }
     $self->{parser_state} = 1;
   } elsif ($tagname eq "a" && defined $self->{parser_state}) {
-    warn "  file name = " .  $attr->{href} if $self->{debug};
-    $self->{current_file}->{filename} = $attr->{href} if $attr->{href};
+    warn "  file name = " .  $attr->{href} if defined $self->{debug};
+    $self->{current_file}->{filename} = $attr->{href} if defined $attr->{href};
     $self->{parser_state} = 1;
   }
 }
@@ -196,7 +183,7 @@ sub _parse_html_apache {
     return unless $self->{parser_state};
 
     if ($self->{parser_state} == 2) {
-      warn "The title is: $origtext" if $self->{debug};
+      #warn "The title is: $origtext";
       if ($origtext =~ /^Index of (.+)$/) {
         $self->{directory} = $1;
       }
@@ -213,7 +200,7 @@ sub _parse_html_apache {
     $self->{parser_state} = 2;
   } elsif ($tagname eq "pre") {
     $self->{parser_state} = 1;
-  } elsif (($tagname eq "img" || $tagname eq "hr") && defined $self->{parser_state}) {
+  } elsif ($tagname eq "img" && defined $self->{parser_state}) {
     if (defined $self->{current_file} && $self->{current_file}->{filename} !~ /^\?/ && $self->{current_file}->{type} !~ /Icon/) {
       my $entry = WWW::IndexParser::Entry->new;
       $entry->filename($self->{current_file}->{filename}) if defined $self->{current_file}->{filename};
@@ -222,16 +209,13 @@ sub _parse_html_apache {
       $entry->size($self->{current_file}->{size}) if defined $self->{current_file}->{size};
       $entry->size_units($self->{current_file}->{size_units}) if defined $self->{current_file}->{size_units};
       push @{$self->{files}}, $entry;
-      warn "Added " . $self->{current_file}->{filename} if $self->{debug};
       delete $self->{current_file};
     }
-    warn "Possible new file:" . $attr->{alt} if $self->{debug};
+    #warn "Possible new file:" . $attr->{alt} if defined $self->{debug};
     $self->{current_file}->{type} = $attr->{alt} if defined $attr->{alt};
   } elsif ($tagname eq "a" && defined $self->{parser_state}) {
-    warn "  file name = " .  $attr->{href} if $self->{debug};
+    #warn "  file name = " .  $attr->{href} if defined $self->{debug};
     $self->{current_file}->{filename} = $attr->{href} if defined $attr->{href};
-  } else {
-    warn $tagname if $self->{debug};
   }
 }
 
@@ -254,10 +238,7 @@ sub _parse_html_iis {
       return;
     }
     if ($origtext =~ /\s*(\w+),\s+(\w+)\s+(\d+),\s+(\d{4})\s+(\d{1,2}):(\d\d) (AM|PM)\s+([\d\.]+)/) {
-      my $hour_of_day = $5;
-      $hour_of_day = 0 if ($7 eq 'AM' && $hour_of_day eq 12);
-      $hour_of_day += 12 if ($7 eq 'PM' && $hour_of_day ne 12);
-      my $time = timelocal(0, $6, $hour_of_day, $3, $months->{$2}, $4-1900);
+      my $time = timelocal(0, $6, $7eq'PM'?12+$5:$5, $3, $months->{$2}, $4-1900);
       $self->{current_file}->{time} = $time;
       $self->{current_file}->{size} = $8;
     }
@@ -276,7 +257,7 @@ sub _parse_html_iis {
       delete $self->{current_file};
     }
   } elsif ($tagname eq "a" && defined $self->{parser_state}) {
-    warn "  file name = " .  $attr->{href} if $self->{debug};
+    warn "  file name = " .  $attr->{href} if defined $self->{debug};
     $self->{current_file}->{filename} = $attr->{href} if defined $attr->{href};
   }
 }
@@ -310,7 +291,7 @@ by the autoindex generated: type() and size_units().
 
 =over 4
 
-=item new ( url => $url, timeout => $seconds, proxy => $proxy_url, debug => 1  )
+=item new ( url => $url, timeout => $seconds, proxy => $proxy_url  )
 
 When called with a URL to examine, this method does not return an object, 
 but an array of WWW::IndexParser::Entry obects, one per entry in the 
@@ -332,12 +313,6 @@ The timeout for the request to fetch data, default 10 seconds.
 
 A proxy server URL, eg, 'http://proxy:3128/'.
 
-=item debug
-
-Decide if to print parsing debug information. Set to 0 (the default) to 
-disable, or anything non-false to print. Recommened you use a digit (ie, 1) 
-as this may become a numeric 'level' of debug in the future.
-
 =back
 
 
@@ -360,7 +335,7 @@ any
 
 =head1 BUGS
 
-Currently only supports Apache, IIS and Tomcat style auto indexes. Send suggestions for new Auto-Indexes to support to the author (along with sample HTML)!
+Currently only supports Apache auto index.
 
 =head1 AUTHOR
 
@@ -368,7 +343,7 @@ James Bromberger E<lt>james@rcpt.toE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 James Bromberger. All rights reserved. All rights 
+Copyright (c) 2005 James Bromberger. All rights reserved. All rights 
 reserved. This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
