@@ -3,11 +3,6 @@ use strict;
 use warnings;
 use overload '""' => \&_as_string;
 
-BEGIN {
-  our $VERSION = '0.5.1';
-}
-
-
 sub new {
   my $proto = shift;
   my $class = ref($proto) || $proto;
@@ -28,7 +23,7 @@ sub url {
   my $self = shift;
   if (@_) {
     my $new_url = shift;
-    return unless $new_url =~ m!^\w+://[^:\s/]+(:\d+)?/!;
+    return unless $new_url =~ m!^\w+://[\w\d\.]+(:\d+)?/!;
     $self->{url} = $new_url;
   }
   return $self->{url};
@@ -79,7 +74,6 @@ sub _as_string {
   $string.= sprintf "Size Units: %s\n", $self->size_units if defined $self->size_units;
   $string.= sprintf "Type      : %s\n", $self->type if defined $self->type;
   $string.= sprintf "URL       : %s\n", $self->url if defined $self->url;
-  $string.= sprintf "Time      : %s\n", scalar localtime($self->time) if defined $self->time;
   return $string;
 }
 
